@@ -1,7 +1,9 @@
 context("manipulating taxon concepts")
 
 # Loading installed examples
-load(file.path(path.package("taxlist"), "taxlist_examples/examples.Rda"))
+pat <- system.file("taxlist_examples", "examples.Rda", package = "taxlist")
+
+load(pat)
 
 test_that("function taxon_relations is working", {
 			expect_is(taxon_relations(Easplist), "data.frame")
@@ -45,11 +47,11 @@ test_that("function add_concept is working", {
 			tax_1 <- clean(subset(Easplist, TaxonName == "Cyperus papyrus",
 							slot="names"))
 			tax_1@taxonViews <- tax_1@taxonViews[tax_1@taxonViews$ViewID %in%
-							tax_1@taxonRelations$ViewID,]
+							tax_1@taxonRelations$ViewID, ]
 			tax_2 <- clean(subset(Easplist, TaxonName == "Cyperaceae",
 							slot="names"))
 			tax_2@taxonViews <- tax_2@taxonViews[tax_2@taxonViews$ViewID %in%
-							tax_2@taxonRelations$ViewID,]
+							tax_2@taxonRelations$ViewID, ]
 			expect_is(add_concept(tax_1, tax_2, insert_view=TRUE), "taxlist")
 		}
 )
